<?php
/**
 * Chicago Theme Customizer
 *
 * @package Chicago
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function chicago_customize_register( $wp_customize ) {

	//Include custom controls
	require get_template_directory() . '/inc/customizer-includes/customizer-custom-controls.php';

	$defaults = chicago_get_default_theme_options();

	//Rename title_tagline section to Site Title, Tagline and Logo
	$wp_customize->get_section( 'title_tagline' )->title 		= __( 'Site Title, Tagline and Logo', 'chicago' );
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	$jetpack_logo  = get_option( 'site_logo' );

	//If there logo present from jetpack, the $jetpack_logo['id'] becomes not empty, hence,  the check
    if ( empty( $jetpack_logo['id'] ) ) {
		// Custom Logo (added to Site Title and Tagline section in Theme Customizer)
		$wp_customize->add_setting( 'logo', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo'],
			'sanitize_callback'	=> 'esc_url_raw'
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
			'label'		=> __( 'Logo', 'chicago' ),
			'priority'	=> 100,
			'section'   => 'title_tagline',
	        'settings'  => 'logo',
	    ) ) );

	    $wp_customize->add_setting( 'logo_disable', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo_disable'],
			'sanitize_callback' => 'chicago_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'logo_disable', array(
			'label'    => __( 'Check to disable logo', 'chicago' ),
			'priority' => 101,
			'section'  => 'title_tagline',
			'settings' => 'logo_disable',
			'type'     => 'checkbox',
		) );

	    $wp_customize->add_setting( 'logo_alt_text', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo_alt_text'],
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'logo_alt_text', array(
			'label'    	=> __( 'Logo Alt Text', 'chicago' ),
			'priority'	=> 102,
			'section' 	=> 'title_tagline',
			'settings' 	=> 'logo_alt_text',
			'type'     	=> 'text',
		) );
		// Custom Logo End
	}

	//Header Options
	require get_template_directory() . '/inc/customizer-includes/customizer-header-options.php';

	// Color Scheme
	$wp_customize->add_setting( 'color_scheme', array(
		'capability' 		=> 'edit_theme_options',
		'default'    		=> $defaults['color_scheme'],
		'sanitize_callback'	=> 'sanitize_key',
		'transport'         => 'refresh',
	) );

	$schemes = chicago_color_schemes();

	$choices = array();

	foreach ( $schemes as $scheme ) {
		$choices[ $scheme['value'] ] = $scheme['label'];
	}

	$wp_customize->add_control( 'color_scheme', array(
		'choices'  => $choices,
		'label'    => __( 'Color Scheme', 'chicago' ),
		'priority' => 5,
		'section'  => 'colors',
		'settings' => 'color_scheme',
		'type'     => 'radio',
	) );
	//End Color Scheme
	
	//Theme Options
	require get_template_directory() . '/inc/customizer-includes/customizer-theme-options.php';
	
	//Featured Content
	require get_template_directory() . '/inc/customizer-includes/customizer-featured-content-options.php';

	//Featured Slider
	require get_template_directory() . '/inc/customizer-includes/customizer-featured-slider-options.php';

	// Reset all settings to default
	$wp_customize->add_section( 'chicago_reset_all_settings', array(
		'description'	=> __( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'chicago' ),
		'priority' 		=> 700,
		'title'    		=> __( 'Reset all settings', 'chicago' ),
	) );

	$wp_customize->add_setting( 'reset_all_settings', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_all_settings'],
		'sanitize_callback' => 'chicago_reset_all_settings',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'reset_all_settings', array(
		'label'    => __( 'Check to reset all settings to default', 'chicago' ),
		'section'  => 'chicago_reset_all_settings',
		'settings' => 'reset_all_settings',
		'type'     => 'checkbox',
	) );
	// Reset all settings to default end

	$wp_customize->add_section( 'important_links', array(
		'priority' 		=> 999,
		'title'   	 	=> __( 'Important Links', 'chicago' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'chicago_sanitize_important_link',
	) );

	$wp_customize->add_control( new ChicagoImportantLinks( $wp_customize, 'important_links', array(
        'label'   	=> __( 'Important Links', 'chicago' ),
        'section'  	=> 'important_links',
        'settings' 	=> 'important_links',
        'type'     	=> 'important_links',
    ) ) );  
    //Important Links End

}
add_action( 'customize_register', 'chicago_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function chicago_customize_preview_js() {
	wp_enqueue_script( 'chicago_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
	
	//Flush transients
	chicago_flush_transients();
}
add_action( 'customize_preview_init', 'chicago_customize_preview_js' );

/**
 * Sanitizes Checkboxes
 * @param  $input entered value
 * @return sanitized output
 *
 * @since  Chicago 1.0
 */
function chicago_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } 
    else {
        return '';
    }
}

/**
 * Sanitizes Custom CSS 
 * @param  $input entered value
 * @return sanitized output
 *
 * @since  Chicago 1.0
 */
function chicago_sanitize_custom_css( $input ) {
	if ( $input != '' ) { 
        $input = str_replace( '<=', '&lt;=', $input ); 
        
        $input = wp_kses_split( $input, array(), array() ); 
        
        $input = str_replace( '&gt;', '>', $input ); 
        
        $input = strip_tags( $input ); 

        return $input;
 	}
    else {
    	return '';
    }
}

/**
 * Sanitizes post_id in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since  Chicago 1.0
 */
function chicago_sanitize_post_id( $input ) {
    //check if post exists
	if( get_post( $input ) ) {
		return $input;
    }
    else {
    	return '';
    }
}

/**
 * Sanitizes page in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Chicago 0.1
 */
function chicago_sanitize_page( $input ) {
	if(  get_post( $input ) ){
		return $input;
	}
    else {
    	return '';
    }
}


/**
 * Sanitizes category list in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Chicago 0.1
 */
function chicago_sanitize_category_list( $input ) {
	if ( $input != '' ) { 
		$args = array(
						'type'			=> 'post',
						'child_of'      => 0,
						'parent'        => '',
						'orderby'       => 'name',
						'order'         => 'ASC',
						'hide_empty'    => 0,
						'hierarchical'  => 0,
						'taxonomy'      => 'category',
					); 
		
		$categories = ( get_categories( $args ) );

		$category_list 	=	array();
		
		foreach ( $categories as $category )
			$category_list 	=	array_merge( $category_list, array( $category->term_id ) );

		if ( count( array_intersect( $input, $category_list ) ) == count( $input ) ) {
	    	return $input;
	    } 
	    else {
    		return '';
   		}
    }
    else {
    	return '';
    }
}


/**
 * Sanitizes slider number
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Chicago 0.1
 */
function chicago_sanitize_no_of_slider( $input ) {
	if ( absint( $input ) > 20 ) {
    	return 20;
    } 
    else {
    	return absint( $input );
    }
}

/**
 * Sanitizes feature slider transition effects
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Chicago 0.1
 */
function chicago_sanitize_featured_slide_transition_effects( $input ) {
	$chicago_featured_slide_transition_effects = array_keys( chicago_featured_slide_transition_effects() );
	
	if ( in_array( $input, $chicago_featured_slide_transition_effects ) ) {
		return $input;
	}
	else {
		$defaults = chicago_get_default_theme_options();

		return $defaults['featured_slide_transition_effect'];
	}
}

/**
 * Dummy Sanitizaition function as it contains no value to be sanitized
 */
function chicago_sanitize_important_link() {
	return false;
}

/**
 * Reset all settings to default
 * @param  $input entered value
 * @return sanitized output
 *
 * @since  Chicago 1.0
 */
function chicago_reset_all_settings( $input ) {
	if ( $input == 1 ) {
		//Remove all set values
		remove_theme_mods();

        // Flush out all transients	
        chicago_flush_transients();
    } 
    else {
        return '';
    }
}

/**
 * Custom scripts and styles on customize.php for chicago.
 *
 * @since Chicago 0.1
 */
function chicago_customize_scripts() {
	wp_enqueue_script( 'chicago_customizer_custom', get_template_directory_uri() . '/js/customizer-custom-scripts.js', array( 'jquery' ), '20150315', true );
}
add_action( 'customize_controls_print_footer_scripts', 'chicago_customize_scripts');
